# Halt

[![Build Status](https://travis-ci.org/tubbo/halt.svg?branch=master)](https://travis-ci.org/tubbo/halt)
[![Code Climate](https://codeclimate.com/github/tubbo/halt/badges/gpa.svg)](https://codeclimate.com/github/tubbo/halt)
[![Issue Count](https://codeclimate.com/github/tubbo/halt/badges/issue_count.svg)](https://codeclimate.com/github/tubbo/halt)

Standard error handling for [ActionController][].

## Installation

Add this line to your application's Gemfile:

```ruby
gem 'halt'
```

And then execute:

    $ bundle

Or install it yourself as:

    $ gem install halt

## Usage

Include `Halt` in your `ApplicationController`, and use the `halt` macro
to rescue from exceptions.

```ruby
class ApplicatioNController < ActionController::Base
  include Halt

  halt ActiveRecord::RecordNotFound, with: :not_found
```

Or, you can `halt` from within an action:

```ruby
class PostsController < ApplicationController
  def create
    halt :unauthorized unless current_user.present?
    @post = Post.new post_params

    if @post.save
      redirect_to @post
    else
      render :new
    end
  end

  private

  def post_params
    params.require(:post).permit :title, :body
  end
end
```

## Development

After checking out the repo, run `bin/setup` to install dependencies. Then,
run `rake spec` to run the tests. You can also run `bin/console` for an
interactive prompt that will allow you to experiment.

To install this gem onto your local machine, run `bundle exec rake install`.
To release a new version, update the version number in `version.rb`, and then
run `bundle exec rake release`, which will create a git tag for the version,
push git commits and tags, and push the `.gem` file to
[rubygems.org](https://rubygems.org) via [travis-ci](http://travis-ci.org).

## Contributing

Bug reports and pull requests are welcome on GitHub at
https://github.com/tubbo/halt. This project is intended to be a safe,
welcoming space for collaboration, and contributors are expected to adhere
to the [Contributor Covenant](http://contributor-covenant.org) code of conduct.

## License

The gem is available as open source under the terms of the
[MIT License](http://opensource.org/licenses/MIT).
